==> radical.ensemblemd-0.3.4.tar.gz: radical.ensemblemd-0.3.4/src/radical/ensemblemd/patterns/simulation_analysis_loop.py <==
#!/usr/bin/env python

"""This module defines and implements the Pipeline class.
"""

__author__    = "Ole Weider <ole.weidner@rutgers.edu>"
__copyright__ = "Copyright 2014, http://radical.rutgers.edu"
__license__   = "MIT"

from radical.ensemblemd.exceptions import NotImplementedError
from radical.ensemblemd.execution_pattern import ExecutionPattern

PATTERN_NAME = "SimulationAnalysisLoop"


# ------------------------------------------------------------------------------
#
class SimulationAnalysisLoop(ExecutionPattern):
    """ The Simulation-Analysis pattern.

            .. image:: ../../images/simulation_analysis_pattern.*
               :width: 300pt

        **Data references**:

        The following placeholders can be used to reference the output data
        generated in previous steps accross different instances:

        * ``$PRE_LOOP`` - References the pre_loop step.
        * ``$PREV_SIMULATION`` - References the previous simulation step with the same instance number.
        * ``$PREV_SIMULATION_INSTANCE_Y`` - References instance Y of the previous simulation step.
        * ``$SIMULATION_ITERATION_X_INSTANCE_Y`` - Refernces instance Y of the simulation step of iteration number X.
        * ``$PREV_ANALYSIS`` - References the previous analysis step with the same instance number.
        * ``$PREV_ANALYSIS_INSTANCE_Y`` - References instance Y of the previous analysis step.
        * ``$ANALYSIS_ITERATION_X_INSTANCE_Y`` - Refernces instance Y of the analysis step of iteration number X.

        For example, to reference the file ``output.dat`` in the output
        directory of the previous analysis step with the same instance can be
        referenced from an analysis step as:

        .. code-block:: python

            def simulation_step(self, iteration, instance):
                k = Kernel(name="kernelname")
                k.link_input_data = ["$PREV_ANALYSIS/output.dat]
                # Alternatively: k.copy_input_data to copy the data instead of just linking it
                k.arguments = ["--inputfile1=output.dat"]
                return kg
    """

    #---------------------------------------------------------------------------
    #
    def __init__(self, iterations, simulation_instances=1, analysis_instances=1):
        """Creates a new SimulationAnalysisLoop.

        **Arguments:**

            * **iterations** [`int`]
              The iterations parameter determines the maximum number of
              iterations the simulation-analysis loop is executed. After
              iterations is reached, the loop terminates and `post_loop` is called.

            * **simulation_instances** [`int`]
              The simulation_instances parameter determines the number of independent
              simulation instances launched for each `simulation_step`.

            * **analysis_instances** [`int`]
              The analysis_instances parameter determines the number of independent
              analysis instances launched for each `analysis_step`.

        """
        self._iterations = iterations
        self._simulation_instances = simulation_instances
        self._analysis_instances = analysis_instances

        super(SimulationAnalysisLoop, self).__init__()

    #---------------------------------------------------------------------------
    #
    @property
    def name(self):
        """Returns the name of the pattern.
        """
        return PATTERN_NAME

    #---------------------------------------------------------------------------
    #
    @property
    def iterations(self):
        """Returns the maximum number of loop iterations.
        """
        return self._iterations

    #---------------------------------------------------------------------------
    #
    @property
    def simlation_instances(self):
        """Returns the number of simulation instances per loop iteration.
        """
        return self._simulation_instances

    #---------------------------------------------------------------------------
    #
    @property
    def analysis_instances(self):
        """Returns the number of analysis instances per loop iteration.
        """
        return self._analysis_instances

    #---------------------------------------------------------------------------
    #
    def pre_loop(self):
        """The :class:`radical.ensemblemd.Kernel` returned by `pre_loop` is
        executed before the main simulation-analysis loop is started.

        It can be used for example to set up structures, initialize
        experimental environments and so on.

        **Returns:**

            Implementations of this method **must** return either a single or a list of
            :class:`radical.ensemblemd.Kernel` object(s). An exception is thrown otherwise.

        """
        raise NotImplementedError(
            method_name="pre_loop",
            class_name=type(self))

    #---------------------------------------------------------------------------
    #
    def simulation_step(self, iteration, instance):
        """The :class:`radical.ensemblemd.Kernel` returned by `simulation_step`
        is executed once per loop iteration before `analysis_step`.

        **Arguments:**

            * **iteration** [`int`]
              The iteration parameter is a positive integer and references the
              current iteration of the simulation-analysis loop.

            * **instance** [`int`]
              The instance parameter is a positive integer and references the
              instance of the simulation step, which is in the range
              [1 .. simulation_instances].

        **Returns:**

            Implementations of this method **must** return either a single or a list of
            :class:`radical.ensemblemd.Kernel` object(s). An exception is thrown otherwise.

        """
        raise NotImplementedError(
            method_name="simulation_step",
            class_name=type(self))

    #---------------------------------------------------------------------------
    #
    def analysis_step(self, iteration,instance):
        """The :class:`radical.ensemblemd.Kernel` returned by `analysis_step`
        is executed once per loop iteration after `simulation_step`.

        **Arguments:**

            * **iteration** [`int`]
              The iteration parameter is a positive integer and references the
              current iteration of the simulation-analysis loop.

            * **instance** [`int`]
              The instance parameter is a positive integer and references the
              instance of the simulation step, which is in the range
              [1 .. simulation_instances].

        **Returns:**

            Implementations of this method **must** return either a single or a list of
            :class:`radical.ensemblemd.Kernel` object(s). An exception is thrown otherwise.

        """
        raise NotImplementedError(
          method_name="analysis_step",
          class_name=type(self))

    #---------------------------------------------------------------------------
    #
    def post_loop(self):
        """The :class:`radical.ensemblemd.Kernel` returned by `post_loop` is
        executed after the main simulation-analysis loop has finished.

        It can be used for example to set up structures, initialize
        experimental environments and so on.

        **Returns:**

            Implementations of this method **must** return a single
            :class:`radical.ensemblemd.Kernel` object. An exception is thrown otherwise.

        """
        raise NotImplementedError(
          method_name="post_loop",
          class_name=type(self))

==> radical.ensemblemd-0.3.7.tar.gz: radical.ensemblemd-0.3.7/src/radical/ensemblemd/patterns/simulation_analysis_loop.py <==
#!/usr/bin/env python

"""This module defines and implements the Pipeline class.
"""

__author__    = "Ole Weider <ole.weidner@rutgers.edu>"
__copyright__ = "Copyright 2014, http://radical.rutgers.edu"
__license__   = "MIT"

from radical.ensemblemd.exceptions import NotImplementedError
from radical.ensemblemd.execution_pattern import ExecutionPattern

PATTERN_NAME = "SimulationAnalysisLoop"


# ------------------------------------------------------------------------------
#
class SimulationAnalysisLoop(ExecutionPattern):
    """ The Simulation-Analysis pattern.

            .. image:: ../../images/simulation_analysis_pattern.*
               :width: 300pt

        **Data references**:

        The following placeholders can be used to reference the data during staging
        generated in previous steps accross different instances:

        * ``$PRE_LOOP`` - References the pre_loop step.
        * ``$PREV_SIMULATION`` - References the previous simulation step with the same instance number.
        * ``$PREV_SIMULATION_INSTANCE_Y`` - References instance Y of the previous simulation step.
        * ``$SIMULATION_ITERATION_X_INSTANCE_Y`` - Refernces instance Y of the simulation step of iteration number X.
        * ``$PREV_ANALYSIS`` - References the previous analysis step with the same instance number.
        * ``$PREV_ANALYSIS_INSTANCE_Y`` - References instance Y of the previous analysis step.
        * ``$ANALYSIS_ITERATION_X_INSTANCE_Y`` - Refernces instance Y of the analysis step of iteration number X.

        For example, to reference the file ``output.dat`` in the output
        directory of the previous analysis step with the same instance can be
        referenced from an analysis step as:

        .. code-block:: python

            def simulation_step(self, iteration, instance):
                k = Kernel(name="kernelname")
                k.link_input_data = ["$PREV_ANALYSIS/output.dat]
                # Alternatively: k.copy_input_data to copy the data instead of just linking it
                k.arguments = ["--inputfile1=output.dat"]
                return kg
    """

    #---------------------------------------------------------------------------
    #
    def __init__(self, iterations, simulation_instances=1, analysis_instances=1):
        """Creates a new SimulationAnalysisLoop.

        **Arguments:**

            * **iterations** [`int`]
              The iterations parameter determines the maximum number of
              iterations the simulation-analysis loop is executed. After
              iterations is reached, the loop terminates and `post_loop` is called.

            * **simulation_instances** [`int`]
              The simulation_instances parameter determines the number of independent
              simulation instances launched for each `simulation_step`.

            * **analysis_instances** [`int`]
              The analysis_instances parameter determines the number of independent
              analysis instances launched for each `analysis_step`.

        """
        self._iterations = iterations
        self._simulation_instances = simulation_instances
        self._analysis_instances = analysis_instances

        super(SimulationAnalysisLoop, self).__init__()

    #---------------------------------------------------------------------------
    #
    @property
    def name(self):
        """Returns the name of the pattern.
        """
        return PATTERN_NAME

    #---------------------------------------------------------------------------
    #
    @property
    def iterations(self):
        """Returns the maximum number of loop iterations.
        """
        return self._iterations

    #---------------------------------------------------------------------------
    #
    @property
    def simlation_instances(self):
        """Returns the number of simulation instances per loop iteration.
        """
        return self._simulation_instances

    #---------------------------------------------------------------------------
    #
    @property
    def analysis_instances(self):
        """Returns the number of analysis instances per loop iteration.
        """
        return self._analysis_instances

    #---------------------------------------------------------------------------
    #
    def pre_loop(self):
        """The :class:`radical.ensemblemd.Kernel` returned by `pre_loop` is
        executed before the main simulation-analysis loop is started.

        It can be used for example to set up structures, initialize
        experimental environments and so on.

        **Returns:**

            Implementations of this method **must** return either a single or a list of
            :class:`radical.ensemblemd.Kernel` object(s). An exception is thrown otherwise.

        """
        raise NotImplementedError(
            method_name="pre_loop",
            class_name=type(self))

    #---------------------------------------------------------------------------
    #
    def simulation_step(self, iteration, instance):
        """The :class:`radical.ensemblemd.Kernel` returned by `simulation_step`
        is executed once per loop iteration before `analysis_step`.

        **Arguments:**

            * **iteration** [`int`]
              The iteration parameter is a positive integer and references the
              current iteration of the simulation-analysis loop.

            * **instance** [`int`]
              The instance parameter is a positive integer and references the
              instance of the simulation step, which is in the range
              [1 .. simulation_instances].

        **Returns:**

            Implementations of this method **must** return either a single or a list of
            :class:`radical.ensemblemd.Kernel` object(s). An exception is thrown otherwise.

        """
        raise NotImplementedError(
            method_name="simulation_step",
            class_name=type(self))

    #---------------------------------------------------------------------------
    #
    def analysis_step(self, iteration,instance):
        """The :class:`radical.ensemblemd.Kernel` returned by `analysis_step`
        is executed once per loop iteration after `simulation_step`.

        **Arguments:**

            * **iteration** [`int`]
              The iteration parameter is a positive integer and references the
              current iteration of the simulation-analysis loop.

            * **instance** [`int`]
              The instance parameter is a positive integer and references the
              instance of the simulation step, which is in the range
              [1 .. simulation_instances].

        **Returns:**

            Implementations of this method **must** return either a single or a list of
            :class:`radical.ensemblemd.Kernel` object(s). An exception is thrown otherwise.

        """
        raise NotImplementedError(
          method_name="analysis_step",
          class_name=type(self))

    #---------------------------------------------------------------------------
    #
    def post_loop(self):
        """The :class:`radical.ensemblemd.Kernel` returned by `post_loop` is
        executed after the main simulation-analysis loop has finished.

        It can be used for example to set up structures, initialize
        experimental environments and so on.

        **Returns:**

            Implementations of this method **must** return a single
            :class:`radical.ensemblemd.Kernel` object. An exception is thrown otherwise.

        """
        raise NotImplementedError(
          method_name="post_loop",
          class_name=type(self))
